@REM ***************************************************************************
@REM *
@REM * Licensed Materials - Property of IBM
@REM * 5698-A17
@REM *
@REM * (C) Copyright IBM Corp. 1990, 2009.  All Rights Reserved.
@REM *
@REM * US Government Users Restricted Rights - Use, duplication or
@REM * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@REM *
@REM ***************************************************************************
@REM *
@echo off
rem	The parameters this script needs are distinguished using couples of
rem	keywords. The first value is the option that is a constant identifying the
rem	parameter, the second value is its argument that the script uses.
rem	Here follows the list of all the option keyword: 
rem
rem	-d     (mandatory)	it identifies the Universal Agent installation directory
rem
rem	-h     (mandatory)    	the TWS for z/OS Controller hostname for the socket data 
rem                           provider
rem	
rem	-t     (optional)		it identifies the value in seconds to provide in the TTL 
rem                           parameter for the NAME statement. Default value is 86400
rem
rem	The couples option-argument can be passed in the order you want. 
rem	This script executes checks about the presence of the mandatory options, 
rem	unknown options, and some validation checks are made on the argument values

set keyword1=-d
set key1count=0
set keyword2=-h
set key2count=0
set keyword3=-t
set key3count=0
set usage=?

set UAInstDir=""
set hostname=""
set UA_TTL=0
set ERR_RC=0
set local_dir=%cd%
set local_rc=0
set good_keyword=0

if "%1"=="" goto issue_usage_msg

if exist "%local_dir%\hostfile.txt" del /q /f "%local_dir%\hostfile.txt"
if exist "%local_dir%\TTLfile1.txt" del /q /f "%local_dir%\TTLfile1.txt"
if exist "%local_dir%\TTLfile2.txt" del /q /f "%local_dir%\TTLfile2.txt"
if exist "%local_dir%\TTLfile3.txt" del /q /f "%local_dir%\TTLfile3.txt"
if exist "%local_dir%\TTLfile4.txt" del /q /f "%local_dir%\TTLfile4.txt"

:nextparm

if "%1"=="%keyword1%" goto UADir 
if "%1"=="%keyword2%" goto parse_hostnames
if "%1"=="%keyword3%" goto UATTL
if "%1"=="%usage%" goto issue_usage_msg

if "%1"=="" goto endloop

if "%good_keyword%" EQU "0" (
set ERR_RC=8
goto err_msg_unknown_opt
) else (
set good_keyword=0
)

goto nextparm

:endloop
goto parse_end

:UADir
if not "%key1count%" EQU "0" (
set ERR_RC=8
goto err_msg_more_than_1
)
set UAInstDir=%2

if "%UAInstDir%"=="" goto err_msg_incorrect_value_opt
if not exist "%UAInstDir%\TMAITM6" goto err_msg_incorrect_value_opt

set key1count=1
set good_keyword=1
shift
shift 
goto nextparm

:parse_hostnames
if not "%key2count%" EQU "0" (
set ERR_RC=8
goto err_msg_more_than_1
)
set key2count=1
set good_keyword=1
set hostname=%2

if "%hostname%"=="%keyword1%" goto err_msg_incorrect_value_opt
if "%hostname%"=="%keyword2%" goto err_msg_incorrect_value_opt
if "%hostname%"=="%keyword3%" goto err_msg_incorrect_value_opt
if "%hostname%"=="" goto err_msg_incorrect_value_opt

echo [FE]//SOURCE SOCK hostname SETSOURCENAME=Y>> hostfile.txt

:hostloop
shift 
if "%2"=="%keyword1%" goto endhostloop 
if "%2"=="%keyword2%" goto err_msg_more_than_1
if "%2"=="%keyword3%" goto endhostloop
if "%2"=="" goto endhostloop
echo [IB]//SOURCE SOCK %hostname% SETSOURCENAME=Y>> hostfile.txt
set hostname=%2
goto hostloop

:endhostloop
echo [IE]//SOURCE SOCK %hostname% SETSOURCENAME=Y>> hostfile.txt
shift
goto nextparm

:UATTL
if not "%key3count%" EQU "0" (
set ERR_RC=8
goto err_msg_more_than_1
)
set UA_TTL=%2
set key3count=1
set good_keyword=1

if not "%UA_TTL%" GTR "0" (
set ERR_RC=8
goto err_msg_incorrect_value_opt
)

echo [ST]//NAME ALERT E 86400>> TTLfile1.txt
echo [RT]//NAME ALERT E %UA_TTL%>> TTLfile1.txt
echo [ST]//NAME JOB K 86400>> TTLfile2.txt
echo [RT]//NAME JOB K %UA_TTL%>> TTLfile2.txt
echo [ST]//NAME JOBSTREAM K 86400>> TTLfile3.txt
echo [RT]//NAME JOBSTREAM K %UA_TTL%>> TTLfile3.txt
echo [ST]//NAME CRITICAL K 86400>> TTLfile4.txt
echo [RT]//NAME CRITICAL K %UA_TTL%>> TTLfile4.txt
shift
shift
goto nextparm

:parse_end

if "%key1count%" EQU "0" (
set ERR_RC=8
goto err_msg_mandatory_lack1 
)  

if "%key2count%" EQU "0" (
set ERR_RC=8
goto err_msg_mandatory_lack2 
)  

if not exist "%local_dir%\TWSz851SampleMeta.mdl" (
set ERR_RC=8
goto err_msg_no_metafile
) else (
copy "%local_dir%\TWSz851SampleMeta.mdl" "%local_dir%\TWSz851Meta.mdl"
)

if exist "%local_dir%\hostfile.txt" (
call ParseAndRep "%local_dir%\TWSz851Meta.mdl" "%local_dir%\hostfile.txt"
)

if exist "%local_dir%\TTLfile1.txt" (
call ParseAndRep "%local_dir%\TWSz851Meta.mdl" "%local_dir%\TTLfile1.txt"
)

if exist "%local_dir%\TTLfile2.txt" (
call ParseAndRep "%local_dir%\TWSz851Meta.mdl" "%local_dir%\TTLfile2.txt"
)

if exist "%local_dir%\TTLfile3.txt" (
call ParseAndRep "%local_dir%\TWSz851Meta.mdl" "%local_dir%\TTLfile3.txt"
)

if exist "%local_dir%\TTLfile4.txt" (
call ParseAndRep "%local_dir%\TWSz851Meta.mdl" "%local_dir%\TTLfile4.txt"
)


:install_metafile

set KUMP_DPCONSOLE_NOCONFIRM=Y

cd /d %UAInstDir%\TMAITM6

kumpcon import %local_dir%\TWSz851Meta.mdl

if %ERRORLEVEL%==-1 goto refresh_meta 
goto done

:refresh_meta

kumpcon refresh %local_dir%\TWSz851Meta.mdl

if %ERRORLEVEL%==-1 set local_rc=%ERRORLEVEL%

:done

cd /d %local_dir%

if %local_rc%==0 (
goto issue_succ_msg
) else (
goto exit_script
)

:issue_succ_msg
echo The TEP configuration was successfully completed with the following values:
echo Universal Agent installation directory: %UAInstDir%
echo hostname (last): %hostname%
if "%UA_TTL%" GTR "0" (
echo Universal Agent time to live: %UA_TTL%
)

goto exit_script

:issue_usage_msg
echo USAGE:
echo tepconfig -d Universal Agent install_dir -h hostname... [-t time to live for TWSz monitored data]
goto exit_script

:err_msg_unknown_opt
echo the option %1 is unknown
goto end_msg

:err_msg_no_metafile
echo the sample metafile was not found
goto end_msg

:err_msg_incorrect_value_opt
echo the value specified %2 is not valid
goto end_msg

:err_msg_mandatory_lack1
echo the mandatory option %keyword1% is missing
goto end_msg

:err_msg_mandatory_lack2
echo the mandatory option %keyword2% is missing
goto end_msg

:err_msg_more_than_1
echo the option %1 has been specified more than one time
goto end_msg

:end_msg
echo NO ACTION WAS TAKEN, EXITING WITH RC=%ERR_RC%
goto exit_script

:exit_script
if exist "%local_dir%\hostfile.txt" del /q /f "%local_dir%\hostfile.txt"
if exist "%local_dir%\TTLfile1.txt" del /q /f "%local_dir%\TTLfile1.txt"
if exist "%local_dir%\TTLfile2.txt" del /q /f "%local_dir%\TTLfile2.txt"
if exist "%local_dir%\TTLfile3.txt" del /q /f "%local_dir%\TTLfile3.txt"
if exist "%local_dir%\TTLfile4.txt" del /q /f "%local_dir%\TTLfile4.txt"
